@@ -318,6 +318,7 @@ type PartParsedData = Map Int [Dynamic]
 
 data CmdDescStack = StackBottom (Deque PartDesc)
                   | StackLayer  (Deque PartDesc) String CmdDescStack
+  deriving Show
 
 descStackAdd :: PartDesc -> CmdDescStack -> CmdDescStack
 descStackAdd d = \case
@@ -1023,7 +1024,6 @@ runCmdParserAExt mTopLevel inputInitial cmdParser =
               ++ " with remaining input: "
               ++ show input
             ]
-          failureCurrentShallowRerun
           processParsedParts $ nextF monadMisuseError
         continueOrMisuse :: Maybe p -> m (CmdParser f out a)
         continueOrMisuse = maybe monadMisuseError (processParsedParts . nextF)
@@ -1143,7 +1143,12 @@ runCmdParserAExt mTopLevel inputInitial cmdParser =
       mModify (descStackAdd desc)
       nextF =<< iterM processCmdShallow alt
 
-  failureCurrentShallowRerun
+  -- currently unused; was previously used during failure in
+  -- processParsedParts. Using this leads to duplicated descs, but I fear
+  -- that not using it also leads to certain problems (missing children?).
+  -- Probably want to re-write into proper two-phase 1) obtain desc 2) run
+  -- parser, like the applicative approach.
+  _failureCurrentShallowRerun
     :: ( m ~ MultiRWSS.MultiRWST r w s m0
        , MonadMultiState (CmdParser f out ()) m
        , MonadMultiState (CommandDesc out) m
@@ -1151,7 +1156,7 @@ runCmdParserAExt mTopLevel inputInitial cmdParser =
        , Monad m0
        )
     => m ()
-  failureCurrentShallowRerun = do
+  _failureCurrentShallowRerun = do
     parser :: CmdParser f out () <- mGet
     cmd :: CommandDesc out <-
       MultiRWSS.withMultiStateS emptyCommandDesc
